@@ -8,7 +8,7 @@ use Try::Tiny;
 sub new {
     my $class = shift;
     bless {
-        env  => 'development',
+        env      => $ENV{PLACK_ENV},
         loader   => 'Plack::Loader',
         includes => [],
         modules  => [],
@@ -60,8 +60,10 @@ sub parse_options {
             $v[0] =~ tr/-/_/;
             if (@v == 2) {
                 push @options, @v;
+            } elsif ($v[0] =~ s/^(disable|enable)_//) {
+                push @options, $v[0], $1 eq 'enable';
             } else {
-                push @options, @v, shift @ARGV;
+                push @options, $v[0], shift @ARGV;
             }
         } else {
             push @argv, $_;
@@ -210,7 +212,8 @@ sub run {
 
     my $app = $self->locate_app(@args);
 
-    if ($self->{env} eq 'development') {
+    $ENV{PLACK_ENV} ||= $self->{env} || 'development';
+    if ($ENV{PLACK_ENV} eq 'development') {
         $app = $self->prepare_devel($app);
     }
 
